@@ -99,7 +99,10 @@ class StoragePoolsClient(object):
                              hot_tier_size=None,
                              enable_hot_tier_auto_resize=None,
                              labels=None,
-                             unified_pool=None):
+                             unified_pool=None,
+                             qos_type=None,
+                             storage_pool_type=None,
+                             ):
     """Parses the command line arguments for Create Storage Pool into a config."""
     return self._adapter.ParseStoragePoolConfig(
         name=name,
@@ -120,6 +123,8 @@ class StoragePoolsClient(object):
         enable_hot_tier_auto_resize=enable_hot_tier_auto_resize,
         labels=labels,
         unified_pool=unified_pool,
+        qos_type=qos_type,
+        storage_pool_type=storage_pool_type,
     )
 
   def ListStoragePools(self, location_ref, limit=None):
@@ -178,7 +183,9 @@ class StoragePoolsClient(object):
                                     total_iops=None,
                                     hot_tier_size=None,
                                     enable_hot_tier_auto_resize=None,
-                                    labels=None):
+                                    qos_type=None,
+                                    labels=None,
+                                    ):
     """Parses updates into a storage pool config.
 
     Args:
@@ -194,6 +201,7 @@ class StoragePoolsClient(object):
       hot_tier_size: int, hot tier size of the storage pool
       enable_hot_tier_auto_resize: bool, whether hot tier auto resize is enabled
       for the storage pool
+      qos_type: qos (quality of service) type of the storage pool
       labels: LabelsValue message, the new labels value, if any.
 
     Returns:
@@ -211,7 +219,8 @@ class StoragePoolsClient(object):
         total_iops=total_iops,
         hot_tier_size=hot_tier_size,
         enable_hot_tier_auto_resize=enable_hot_tier_auto_resize,
-        labels=labels
+        qos_type=qos_type,
+        labels=labels,
     )
     return storage_pool
 
@@ -310,8 +319,10 @@ class StoragePoolsAdapter(object):
       total_iops,
       hot_tier_size,
       enable_hot_tier_auto_resize,
+      qos_type,
       labels,
       unified_pool,
+      storage_pool_type,
   ):
     """Parses the command line arguments for Create Storage Pool into a config.
 
@@ -333,8 +344,10 @@ class StoragePoolsAdapter(object):
       hot_tier_size: Hot tier size of the Storage Pool
       enable_hot_tier_auto_resize: Bool on whether hot tier auto resize is
         enabled
+      qos_type: qos (quality of service) type of the storage pool
       labels: the parsed labels value
       unified_pool: Bool on whether the Storage Pool is a unified pool
+      storage_pool_type: Type of the Storage Pool
 
     Returns:
       The configuration that will be used as the request body for creating a
@@ -367,9 +380,13 @@ class StoragePoolsAdapter(object):
       storage_pool.hotTierSizeGib = hot_tier_size
     if enable_hot_tier_auto_resize is not None:
       storage_pool.enableHotTierAutoResize = enable_hot_tier_auto_resize
+    if qos_type is not None:
+      storage_pool.qosType = qos_type
     storage_pool.labels = labels
     if unified_pool is not None:
       storage_pool.unifiedPool = unified_pool
+    if storage_pool_type is not None:
+      storage_pool.type = storage_pool_type
     return storage_pool
 
   def ParseUpdatedStoragePoolConfig(
@@ -386,6 +403,7 @@ class StoragePoolsAdapter(object):
       total_iops=None,
       hot_tier_size=None,
       enable_hot_tier_auto_resize=None,
+      qos_type=None,
   ):
     """Parse update information into an updated Storage Pool message."""
     if capacity is not None:
@@ -408,6 +426,8 @@ class StoragePoolsAdapter(object):
       storagepool_config.hotTierSizeGib = hot_tier_size
     if enable_hot_tier_auto_resize is not None:
       storagepool_config.enableHotTierAutoResize = enable_hot_tier_auto_resize
+    if qos_type is not None:
+      storagepool_config.qosType = qos_type
     if labels is not None:
       storagepool_config.labels = labels
     return storagepool_config
