@@ -15,11 +15,13 @@
 """Flags and helpers for the compute interconnects commands."""
 
 import collections
+import copy
 
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.compute import completers as compute_completers
 from googlecloudsdk.command_lib.compute import flags as compute_flags
+from googlecloudsdk.command_lib.compute import resource_manager_tags_utils
 from googlecloudsdk.command_lib.util.apis import arg_utils
 
 _BANDWIDTH_CHOICES = collections.OrderedDict([
@@ -149,17 +151,21 @@ def AddEnableAdmin(parser):
       """)
 
 
-def AddBandwidth(parser, required):
+def AddBandwidth(parser, required, release_track=base.ReleaseTrack.GA):
   """Adds bandwidth flag to the argparse.ArgumentParser.
 
   Args:
     parser: The argparse parser.
     required: A boolean indicates whether the Bandwidth is required.
+    release_track: Depending on which release track is specified, different
+      bandwidth options will be surfaced to customers.
   """
   help_text = """\
       Provisioned capacity of the attachment.
       """
-  choices = _BANDWIDTH_CHOICES
+  choices = copy.deepcopy(_BANDWIDTH_CHOICES)
+  if release_track in (base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA):
+    choices['400g'] = '400 Gbit/s'
 
   base.ChoiceArgument(
       '--bandwidth',
@@ -618,32 +624,21 @@ def AddTunnelEndpointIpAddress(parser, required=True):
   )
 
 
-def AddEnableMulticast(parser, update=False):
+def AddEnableMulticast(parser):
   """Adds enableMulticast flag to the argparse.ArgumentParser.
 
   Args:
     parser: The argparse parser.
-    update: A boolean indicates whether the incoming request is an update.
   """
-  if update:
-    # Update command.
-    help_text = """\
-      When enabled, the attachment will be able to carry multicast traffic.
-      Use --no-enable-multicast to disable it.
-      """
-  else:
-    # Create command for partner attachments, backend default behavior is to
-    # disabled if not specified.
-    help_text = """\
-      If supplied, the attachment will be able to carry multicast traffic.
-      If not provided on creation, defaults to disabled. Use
-      --no-enable-multicast to disable it.
-      """
   parser.add_argument(
       '--enable-multicast',
       default=None,
       action='store_true',
-      help=help_text,
+      help="""\
+      If supplied, the attachment will be able to carry multicast traffic.
+      Defaults to disabled. This property can only be set during attachment
+      creation and cannot be modified later.
+      """,
   )
 
 
@@ -709,3 +704,34 @@ def AddCandidateCustomerRouterIpv6Address(parser):
       2001:db8::2/125
       """,
   )
+
+
+def AddResourceManagerTags(parser):
+  """Adds the --resource-manager-tags flag to the argparse.ArgumentParser."""
+  parser.add_argument(
+      '--resource-manager-tags',
+      type=arg_parsers.ArgDict(),
+      metavar='KEY=VALUE',
+      help="""\
+          A comma-separated list of Resource Manager tags to apply to the interconnect.
+      """,
+  )
+
+
+def CreateInterconnectAttachmentParams(messages, resource_manager_tags):
+  """Converts resource manager tags argument into InterconnectAttachmentParams."""
+  resource_manager_tags_map = (
+      resource_manager_tags_utils.GetResourceManagerTags(
+          resource_manager_tags
+      )
+  )
+  params = messages.InterconnectAttachmentParams
+  additional_properties = [
+      params.ResourceManagerTagsValue.AdditionalProperty(key=key, value=value)
+      for key, value in sorted(resource_manager_tags_map.items())
+  ]
+  return params(
+      resourceManagerTags=params.ResourceManagerTagsValue(
+          additionalProperties=additional_properties
+      )
+  )
