@@ -14,13 +14,11 @@
 # limitations under the License.
 """Flags for the compute zone vm extension policies commands."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 import functools
+import textwrap
 
 from googlecloudsdk.calliope import arg_parsers
+from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.command_lib.compute import flags as compute_flags
 from googlecloudsdk.command_lib.util.args import labels_util
 from googlecloudsdk.core.util import files
@@ -30,7 +28,7 @@ def AddPolicyDescription(parser):
   """Adds the Description flag."""
   parser.add_argument(
       '--description',
-      help='An optional textual description for the this extension policy.',
+      help='An optional text description for the extension policy.',
   )
 
 
@@ -69,14 +67,16 @@ def AddPolicyPriority(parser):
       '--priority',
       type=functools.partial(ValidatePriority, min_val=0, max_val=65535),
       default=1000,
-      help="""
+      help=textwrap.dedent("""\
       The priority of the policy. Lower the number, higher the priority.
-      When two policies tries to apply the same extension, the one with the higher priority takes precedence.
-      If the priority is the same, the one with the more recent update timestamp takes precedence.
-      When a policy is deleted, the extension would remain installed on the VM if a lower priority policy still applies.
+      When two policies try to apply the same extension to a VM, the policy with
+      higher priority takes precedence. If the priorities are the same, the
+      policy with the more recent update timestamp takes precedence. If a policy
+      is deleted, the extension remains installed on the VM if a lower-priority
+      policy still applies.
 
       Range from 0 to 65535. Default is 1000.
-      """,
+      """),
   )
 
 
@@ -89,14 +89,19 @@ def AddExtensionVersion(parser):
       metavar='KEY=VALUE',
       action=arg_parsers.StoreOnceAction,
       required=False,
-      help="""
+      help=textwrap.dedent("""\
       A comma separated key:value list where the key is the extension name and the value is the
       desired version for the given extension. The extension name must be one of the extensions
       specified in the --extensions flag. If no version is specified for an
       extension, the latest version will be used and will be upgraded automatically.
 
       E.g. --version=filestore=123ABC,ops-agent=456DEF
-      """)
+
+      Raises:
+        ArgumentTypeError: If the extension name is not specified in the
+        --extensions flag.
+      """),
+  )
 
 
 def AddExtensionConfigs(parser):
@@ -108,13 +113,18 @@ def AddExtensionConfigs(parser):
       metavar='KEY=VALUE',
       action=arg_parsers.StoreOnceAction,
       required=False,
-      help="""
+      help=textwrap.dedent("""\
       A comma separated key:value list where the key is the extension name and the value is the
       desired config for the given extension. The extension name must be one of the extensions
       specified in the --extensions flag.
 
-      E.g. --config=filestore=,ops-agent=
-      """)
+      E.g. --config=filestore='filestore config',ops-agent='ops agent config'
+
+      Raises:
+        ArgumentTypeError: If the extension name is not specified in the
+        --extensions flag.
+      """),
+  )
 
 
 def AddExtensionConfigsFromFile(parser):
@@ -126,14 +136,15 @@ def AddExtensionConfigsFromFile(parser):
       metavar='KEY=FILE_PATH',
       action=arg_parsers.StoreOnceAction,
       required=False,
-      help="""
+      help=textwrap.dedent("""\
       Same as --config except that the value for the entry will be read from a
       local file. The extension name must be one of the extensions specified in
       the --extensions flag.
 
       It is an error to specify the same extension in both --config and
       --config-from-file.
-      """)
+      """),
+  )
 
 
 def AddPolicyInclusionLabels(parser):
@@ -142,7 +153,7 @@ def AddPolicyInclusionLabels(parser):
       '--inclusion-labels',
       action='append',
       default=[],
-      help="""
+      help=textwrap.dedent("""\
       A list of inclusion labels to select the target VMs.
 
       The expected format for a single selector is "key1=value1,key2=value2".
@@ -157,7 +168,7 @@ def AddPolicyInclusionLabels(parser):
       - VM3: env=prod
 
       If not specified, ALL VMs in the zone will be selected.
-      """,
+      """),
   )
 
 
@@ -200,22 +211,25 @@ def ParseExtensionConfigs(extensions, configs, config_from_file=None):
     config_extensions_set = set(configs.keys())
     extra_extensions = config_extensions_set - extensions_set
     if extra_extensions:
-      raise ValueError(
-          f'Extensions {extra_extensions} from --config are not specified in the'
-          f' --extensions flag. {extensions}'
+      raise exceptions.BadArgumentException(
+          '--config',
+          f'Extensions {extra_extensions} from --config are not specified in'
+          f' the --extensions flag. {extensions}'
       )
   if config_from_file:
     config_from_file_extensions_set = set(config_from_file.keys())
     extra_extensions = config_from_file_extensions_set - extensions_set
     if extra_extensions:
-      raise ValueError(
+      raise exceptions.BadArgumentException(
+          '--config-from-file',
           f'Extensions {extra_extensions} from --config-from-file are not'
           f' specified in the --extensions flag. {extensions}'
       )
   if configs and config_from_file:
     common_extensions = set(configs.keys()) & set(config_from_file.keys())
     if common_extensions:
-      raise ValueError(
+      raise exceptions.BadArgumentException(
+          '--config and --config-from-file',
           f'Extensions {common_extensions} are specified in both --config and'
           ' --config-from-file.'
       )
@@ -229,9 +243,10 @@ def ParseExtensionVersions(extensions, versions):
   versions_extensions_set = set(versions.keys())
   extra_extensions = versions_extensions_set - extensions_set
   if extra_extensions:
-    raise ValueError(
-        f'Extensions {extra_extensions} from --version are not specified in \
-        the --extensions flag. {extensions}'
+    raise exceptions.BadArgumentException(
+        '--version',
+        f'Extensions {extra_extensions} from --version are not specified in'
+        f' the --extensions flag. {extensions}'
     )
 
 
@@ -245,7 +260,7 @@ def _GetConfigs(args):
       try:
         configs[extension] = files.ReadFileContents(file_path)
       except files.Error as e:
-        raise ValueError(
+        raise exceptions.BadFileException(
             f'Could not read config file [{file_path}] for extension'
             f' [{extension}]: {e}'
         )
