@@ -52,3 +52,42 @@ def AddPostgresqlObjectIdentifier(parser):
       '--postgresql-table',
       help="""PostgreSQL table for the object.""",
       required=True)
+
+
+def AddSqlServerObjectIdentifier(parser):
+  """Adds a --sqlserver-schema & --sqlserver-table flags to the given parser."""
+  sqlserver_object_parser = parser.add_group()
+  sqlserver_object_parser.add_argument(
+      '--sqlserver-schema',
+      help="""SQL Server schema for the object.""",
+      required=True,
+  )
+  sqlserver_object_parser.add_argument(
+      '--sqlserver-table',
+      help="""SQL Server table for the object.""",
+      required=True,
+  )
+
+
+def AddSalesforceObjectIdentifier(parser):
+  """Adds a --salesforce-object-name flag to the given parser."""
+  salesforce_object_parser = parser.add_group()
+  salesforce_object_parser.add_argument(
+      '--salesforce-object-name',
+      help="""Salesforce object name.""",
+      required=True,
+  )
+
+
+def AddSpannerObjectIdentifier(parser):
+  """Adds a --spanner-schema & --spanner-table flag to the given parser."""
+  spanner_object_parser = parser.add_group()
+  spanner_object_parser.add_argument(
+      '--spanner-schema',
+      help="""Spanner schema name.""",
+  )
+  spanner_object_parser.add_argument(
+      '--spanner-table',
+      help="""Spanner table name.""",
+      required=True,
+  )
