@@ -40,6 +40,7 @@ from .content import (
     Part,
     PrebuiltVoiceConfig,
     ProactivityConfig,
+    ReplicatedVoiceConfig,
     RetrievalMetadata,
     SafetyRating,
     SafetySetting,
@@ -148,6 +149,7 @@ from .tool import (
     FunctionResponsePart,
     GoogleMaps,
     GoogleSearchRetrieval,
+    PartialArg,
     RagRetrievalConfig,
     Retrieval,
     RetrievalConfig,
@@ -210,6 +212,7 @@ __all__ = (
     'Part',
     'PrebuiltVoiceConfig',
     'ProactivityConfig',
+    'ReplicatedVoiceConfig',
     'RetrievalMetadata',
     'SafetyRating',
     'SafetySetting',
@@ -304,6 +307,7 @@ __all__ = (
     'FunctionResponsePart',
     'GoogleMaps',
     'GoogleSearchRetrieval',
+    'PartialArg',
     'RagRetrievalConfig',
     'Retrieval',
     'RetrievalConfig',
