@@ -20,6 +20,7 @@ from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.container.fleet import client
+from googlecloudsdk.api_lib.container.fleet import types
 from googlecloudsdk.api_lib.container.fleet import util
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import parser_arguments
@@ -29,9 +30,9 @@ from googlecloudsdk.command_lib.container.fleet import update_mask
 from googlecloudsdk.command_lib.container.fleet import util as fleet_util
 from googlecloudsdk.command_lib.util.args import labels_util
 from googlecloudsdk.core import log
-from googlecloudsdk.generated_clients.apis.gkehub.v1alpha import gkehub_v1alpha_messages as messages
 
 
+@base.DefaultUniverseOnly
 class Update(base.UpdateCommand):
   """Update a fleet.
 
@@ -56,7 +57,7 @@ class Update(base.UpdateCommand):
     flags.AddDefaultClusterConfig()
     labels_util.AddUpdateLabelsFlags(parser)
 
-  def Run(self, args: parser_extensions.Namespace) -> messages.Operation:
+  def Run(self, args: parser_extensions.Namespace) -> types.Operation:
     """Runs the fleet update command.
 
     User specified --format takes the highest priority. If not specified, it
@@ -82,23 +83,25 @@ class Update(base.UpdateCommand):
       A completed update operation; if `--async` is specified, return a
       long-running operation to be polled manually.
     """
-    flag_parser = fleet_flags.FleetFlagParser(
-        args, release_track=base.ReleaseTrack.ALPHA
-    )
+    flag_parser = fleet_flags.FleetFlagParser(args, self.ReleaseTrack())
 
     if '--format' not in args.GetSpecifiedArgNames():
       if flag_parser.Async():
         args.format = fleet_util.OPERATION_FORMAT
       else:
         args.format = fleet_util.FLEET_FORMAT
-    fleetclient = client.FleetClient(release_track=base.ReleaseTrack.ALPHA)
+    fleetclient = client.FleetClient(self.ReleaseTrack())
 
     # update GCP labels for namespace resource
-    mask = []
-    labels_diff = labels_util.Diff.FromUpdateArgs(args)
     new_labels = None
-    if labels_diff.MayHaveUpdates():
+    mask = []
+
+    # Fetch existing fleet.
+    current_fleet = None
+    labels_diff = labels_util.Diff.FromUpdateArgs(args)
+    if labels_diff.MayHaveUpdates() or update_mask.HasBinauthzConfig(args):
       current_fleet = fleetclient.GetFleet(flag_parser.Project())
+
       new_labels = labels_diff.Apply(
           fleetclient.messages.Fleet.LabelsValue,
           current_fleet.labels,
@@ -108,7 +111,8 @@ class Update(base.UpdateCommand):
 
     if update_mask.GetFleetUpdateMask(args):
       mask.append(update_mask.GetFleetUpdateMask(args))
-    fleet = flag_parser.Fleet()
+
+    fleet = flag_parser.Fleet(current_fleet)
     fleet.labels = new_labels
     req = flag_parser.messages.GkehubProjectsLocationsFleetsPatchRequest(
         fleet=fleet,
@@ -125,9 +129,7 @@ class Update(base.UpdateCommand):
       )
       return operation
 
-    operation_client = client.OperationClient(
-        release_track=base.ReleaseTrack.ALPHA
-    )
+    operation_client = client.OperationClient(self.ReleaseTrack())
     operation_ref = util.OperationRef(operation)
     completed_operation = operation_client.Wait(operation_ref)
     log.UpdatedResource(
