@@ -28,21 +28,29 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.dataproc import flags
 from googlecloudsdk.core import log
 
+DETAILED_HELP = {
+    'EXAMPLES':
+        """\
+      To instantiate a workflow template 'my-template' in region 'us-central1'
+      with parameter set 'param1'='value1' and 'param2'='value2', run:
 
-def _CommonArgs(parser):
-  flags.AddTimeoutFlag(parser, default='35m')
-  base.ASYNC_FLAG.AddToParser(parser)
-  flags.AddParametersFlag(parser)
+        $ {command} my-template --region=us-central1 --parameters="param1=value1,param2=value2"
+      """,
+}
 
 
-@base.ReleaseTracks(base.ReleaseTrack.GA)
 class Instantiate(base.CreateCommand):
   """Instantiate a workflow template."""
 
-  @staticmethod
-  def Args(parser):
-    _CommonArgs(parser)
-    flags.AddTemplateResourceArg(parser, 'run', api_version='v1')
+  detailed_help = DETAILED_HELP
+
+  @classmethod
+  def Args(cls, parser):
+    dataproc = dp.Dataproc(cls.ReleaseTrack())
+    flags.AddTimeoutFlag(parser, default='24h')
+    base.ASYNC_FLAG.AddToParser(parser)
+    flags.AddParametersFlag(parser)
+    flags.AddTemplateResourceArg(parser, 'run', dataproc.api_version)
 
   def Run(self, args):
     dataproc = dp.Dataproc(self.ReleaseTrack())
@@ -71,40 +79,3 @@ class Instantiate(base.CreateCommand):
     operation = util.WaitForWorkflowTemplateOperation(
         dataproc, operation, timeout_s=args.timeout)
     return operation
-
-
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
-class InstantiateBeta(Instantiate):
-  """Instantiate a workflow template."""
-
-  @staticmethod
-  def Args(parser):
-    _CommonArgs(parser)
-    flags.AddTemplateResourceArg(parser, 'run', api_version='v1beta2')
-
-  def Run(self, args):
-    dataproc = dp.Dataproc(self.ReleaseTrack())
-    msgs = dataproc.messages
-    template_ref = args.CONCEPTS.template.Parse()
-
-    instantiate_request = dataproc.messages.InstantiateWorkflowTemplateRequest()
-    instantiate_request.requestId = uuid.uuid4().hex  # request UUID
-    if args.parameters:
-      instantiate_request.parameters = encoding.DictToAdditionalPropertyMessage(
-          args.parameters,
-          msgs.InstantiateWorkflowTemplateRequest.ParametersValue)
-
-    request = msgs.DataprocProjectsRegionsWorkflowTemplatesInstantiateRequest(
-        instantiateWorkflowTemplateRequest=instantiate_request,
-        name=template_ref.RelativeName())
-
-    operation = dataproc.client.projects_regions_workflowTemplates.Instantiate(
-        request)
-    if args.async_:
-      log.status.Print('Instantiating [{0}] with operation [{1}].'.format(
-          template_ref.Name(), operation.name))
-      return
-
-    operation = util.WaitForWorkflowTemplateOperation(
-        dataproc, operation, timeout_s=args.timeout)
-    return operation
