@@ -35,8 +35,10 @@ def _AddArgsCommon(parser):
   flags.GetPolicyAltNameServersArg().AddToParser(parser)
   flags.GetPolicyLoggingArg().AddToParser(parser)
   flags.GetPolicyPrivateAltNameServersArg().AddToParser(parser)
+  flags.GetEnableDns64AllQueriesArg().AddToParser(parser)
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 class CreateGA(base.UpdateCommand):
   r"""Creates a new Cloud DNS policy.
@@ -58,7 +60,8 @@ class CreateGA(base.UpdateCommand):
         --networks=network1,network2 \
         --alternative-name-servers=192.168.1.1,192.168.1.2 \
         --enable-inbound-forwarding \
-        --enable-logging
+        --enable-logging \
+        --enable-dns64-all-queries
   """
 
   @staticmethod
@@ -78,7 +81,10 @@ class CreateGA(base.UpdateCommand):
     policy_name = policy_ref.Name()
 
     policy = messages.Policy(
-        name=policy_name, enableLogging=False, enableInboundForwarding=False)
+        name=policy_name,
+        enableLogging=False,
+        enableInboundForwarding=False,
+    )
 
     if args.IsSpecified('networks'):
       if args.networks == ['']:
@@ -110,6 +116,17 @@ class CreateGA(base.UpdateCommand):
     if args.IsSpecified('enable_logging'):
       policy.enableLogging = args.enable_logging
 
+    if args.IsSpecified('enable_dns64_all_queries'):
+      policy.dns64Config = messages.PolicyDns64Config(
+          scope=messages.PolicyDns64ConfigScope(
+              allQueries=args.enable_dns64_all_queries
+          )
+      )
+    else:
+      policy.dns64Config = messages.PolicyDns64Config(
+          scope=messages.PolicyDns64ConfigScope(allQueries=False)
+      )
+
     if args.IsSpecified('description'):
       policy.description = args.description
 
@@ -123,6 +140,7 @@ class CreateGA(base.UpdateCommand):
     return result
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.BETA)
 class CreateBeta(CreateGA):
   r"""Creates a new Cloud DNS policy.
@@ -145,7 +163,8 @@ class CreateBeta(CreateGA):
         --alternative-name-servers=192.168.1.1,192.168.1.2 \
         --private-alternative-name-servers=100.64.0.1 \
         --enable-inbound-forwarding \
-        --enable-logging
+        --enable-logging \
+        --enable-dns64-all-queries
   """
 
   @staticmethod
@@ -165,7 +184,10 @@ class CreateBeta(CreateGA):
     policy_name = policy_ref.Name()
 
     policy = messages.Policy(
-        name=policy_name, enableLogging=False, enableInboundForwarding=False)
+        name=policy_name,
+        enableLogging=False,
+        enableInboundForwarding=False,
+    )
 
     if args.IsSpecified('networks'):
       if args.networks == ['']:
@@ -197,6 +219,17 @@ class CreateBeta(CreateGA):
     if args.IsSpecified('enable_logging'):
       policy.enableLogging = args.enable_logging
 
+    if args.IsSpecified('enable_dns64_all_queries'):
+      policy.dns64Config = messages.PolicyDns64Config(
+          scope=messages.PolicyDns64ConfigScope(
+              allQueries=args.enable_dns64_all_queries
+          )
+      )
+    else:
+      policy.dns64Config = messages.PolicyDns64Config(
+          scope=messages.PolicyDns64ConfigScope(allQueries=False)
+      )
+
     if args.IsSpecified('description'):
       policy.description = args.description
 
@@ -210,6 +243,7 @@ class CreateBeta(CreateGA):
     return result
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class CreateAlpha(CreateBeta):
   r"""Creates a new Cloud DNS policy.
@@ -232,7 +266,8 @@ class CreateAlpha(CreateBeta):
         --alternative-name-servers=192.168.1.1,192.168.1.2 \
         --private-alternative-name-servers=100.64.0.1 \
         --enable-inbound-forwarding \
-        --enable-logging
+        --enable-logging \
+        --enable-dns64-all-queries
   """
 
   @staticmethod
