@@ -42,8 +42,12 @@ import six
 
 
 @base.UniverseCompatible
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
-                    base.ReleaseTrack.GA)
+@base.ReleaseTracks(
+    base.ReleaseTrack.ALPHA,
+    base.ReleaseTrack.BETA,
+    base.ReleaseTrack.PREVIEW,
+    base.ReleaseTrack.GA,
+)
 class Init(base.Command):
   """Initialize or reinitialize gcloud.
 
@@ -249,9 +253,18 @@ class Init(base.Command):
       return False
     else:
       # Must sign in with new credentials.
+      if console_only or no_browser:
+        sign_in_details = (
+            'selecting "Y" will display a link that can be opened in your'
+            ' browser to complete authentication')
+      else:
+        sign_in_details = (
+            'selecting "Y" will open your browser to the sign-in page'
+            ' where you complete authentication')
       answer = console_io.PromptContinue(
           prompt_string=(
               'You must sign in to continue. Would you like to sign in'
+              ' ({})'.format(sign_in_details)
           )
       )
       if not answer:
@@ -410,13 +423,15 @@ https://console.developers.google.com/apis page.
             'with Compute Engine resources, the default is assumed.').format(
                 name)
         idx = console_io.PromptChoice(
-            [value['name'] for value in values]
-            + ['Do not set default {0}'.format(name)],
+            ['Do not set default {0}'.format(name)]
+            + [value['name'] for value in values],
             message=message, prompt_string=None, allow_freeform=True,
             freeform_suggester=usage_text.TextChoiceSuggester())
-        if idx is None or idx == len(values):
+        # If the user selected "Do not set default {0}" or "None" as the default
+        # value, we should not set the default value.
+        if idx is None or idx == 0:
           return
-        default_value = values[idx]
+        default_value = values[idx-1]
       properties.PersistProperty(properties.VALUES.compute.Property(name),
                                  default_value['name'])
       log.status.write('Your project default Compute Engine {0} has been set '
