@@ -38,6 +38,8 @@ from boto.compat import BytesIO, six, urllib, encodebytes
 from boto.exception import BotoClientError
 from boto.exception import StorageDataError
 from boto.exception import PleaseRetryException
+from boto.exception import ResumableDownloadException
+from boto.exception import ResumableTransferDisposition
 from boto.provider import Provider
 from boto.s3.keyfile import KeyFile
 from boto.s3.user import User
@@ -46,7 +48,7 @@ import boto.utils
 from boto.utils import compute_md5, compute_hash
 from boto.utils import find_matching_headers
 from boto.utils import merge_headers_by_name
-
+from boto.utils import print_to_fd
 
 class Key(object):
     """
@@ -326,9 +328,15 @@ class Key(object):
                 if (name.lower() == 'content-length' and
                         'Content-Range' not in response_headers):
                     self.size = int(value)
+                    self._size_of_range = self.size
                 elif name.lower() == 'content-range':
-                    end_range = re.sub('.*/(.*)', '\\1', value)
-                    self.size = int(end_range)
+                    range_information = re.search(r'(\d+)-(\d+)\/(\d+)', value)
+                    self.size = int(range_information.group(3))  # The object's total size.
+
+                    start_range = int(range_information.group(1))
+                    end_range = int(range_information.group(2))
+                    # Values are zero indexed and inclusive.
+                    self._size_of_range = end_range - start_range + 1
                 elif name.lower() in Key.base_fields:
                     self.__dict__[name.lower().replace('-', '_')] = value
             self.handle_version_headers(self.resp)
@@ -992,11 +1000,14 @@ class Key(object):
             # object.
             amz_server_side_encryption_customer_algorithm = response.getheader(
                 'x-amz-server-side-encryption-customer-algorithm', None)
+            amz_server_side_encryption_aws_kms_key_id = response.getheader(
+                'x-amz-server-side-encryption-aws-kms-key-id', None)
             # The same is applicable for KMS-encrypted objects in gs buckets.
             goog_customer_managed_encryption = response.getheader(
                 'x-goog-encryption-kms-key-name', None)
             if (amz_server_side_encryption_customer_algorithm is None and
-                    goog_customer_managed_encryption is None):
+                    goog_customer_managed_encryption is None and
+                    amz_server_side_encryption_aws_kms_key_id is None):
                 if self.etag != '"%s"' % md5:
                     raise provider.storage_data_error(
                         'ETag from S3 did not match computed MD5. '
@@ -1553,7 +1564,7 @@ class Key(object):
             cb(data_len, cb_size)
         try:
             for key_bytes in self:
-                print(key_bytes, file=fp, end='')
+                print_to_fd(six.ensure_binary(key_bytes), file=fp, end=b'')
                 data_len += len(key_bytes)
                 for alg in digesters:
                     digesters[alg].update(key_bytes)
@@ -1564,6 +1575,12 @@ class Key(object):
                     if i == cb_count or cb_count == -1:
                         cb(data_len, cb_size)
                         i = 0
+            if hasattr(self, '_size_of_range') and data_len < self._size_of_range:
+                raise ResumableDownloadException(
+                    'Download stream truncated. Received {} of {} bytes.'.format(
+                        data_len, self._size_of_range),
+                    ResumableTransferDisposition.WAIT_BEFORE_RETRY
+                )
         except IOError as e:
             if e.errno == errno.ENOSPC:
                 raise StorageDataError('Out of space for destination file '
